/** @jsx jsx */
import { jsx } from "theme-ui";
import * as React from "react";
import { auth } from "../../firebase";
import { githubProvider } from "../../firebase/auth";
import GitHubIcon from "../icons/GitHub";
import SocialLoginButton from "../SocialLoginButton";

const GitHubButton: React.FunctionComponent<
  {
    onSuccess?: () => void;
    onError?: (err: any) => void;
  } & React.ButtonHTMLAttributes<HTMLButtonElement>
> = ({ onSuccess, onError, ...restProps }) => {
  return (
    <SocialLoginButton
      onClick={async () => {
        try {
          await auth.signInWithPopup(githubProvider());
          onSuccess && onSuccess();
        } catch (err) {
          console.error("Authentication Error: ", err);
          onError && onError(err);
        }
      }}
      {...restProps}
    >
      <GitHubIcon sx={{ mr: 1 }} size={18} /> Sign in with Github
    </SocialLoginButton>
  );
};

export default GitHubButton;
